#include <gtk/gtklabel.h>
#include <gtk/gtkpixmap.h>
#include <gtk/gtktable.h>
#include "gtktreeitempix.h"

#include "folder_closed.xpm"
#include "folder_opened.xpm"
#include "folder_denied.xpm"


static void gtk_tree_item_pix_class_init (GtkTreeItemPixClass *klass);
static void gtk_tree_item_pix_init       (GtkTreeItemPix *tree_item_pix);
void tree_item_pix_collapse                   (GtkWidget *item, gpointer data);
void tree_item_pix_expand                     (GtkWidget *item, gpointer data);

GtkType
gtk_tree_item_pix_get_type (void)
{

  static GtkType tree_item_pix_type = 0;

  if (!tree_item_pix_type)
    {
      GtkTypeInfo tree_item_pix_info =
      {
        "GtkTreeItemPix",
        sizeof (GtkTreeItemPix),
        sizeof (GtkTreeItemPixClass),
        (GtkClassInitFunc) gtk_tree_item_pix_class_init,
        (GtkObjectInitFunc) gtk_tree_item_pix_init,
        /* reserved_1 */ NULL,
        /* reserved_2 */ NULL,
        (GtkClassInitFunc) NULL,
      };

      tree_item_pix_type = gtk_type_unique (gtk_tree_item_get_type (),
                                            &tree_item_pix_info);
    }

  return tree_item_pix_type;
}

static void
gtk_tree_item_pix_class_init (GtkTreeItemPixClass *class)
{
}

static void
gtk_tree_item_pix_init (GtkTreeItemPix *tree_item_pix)
{
  g_return_if_fail (tree_item_pix != NULL);
  g_return_if_fail (GTK_IS_TREE_ITEM_PIX (tree_item_pix));

  GTK_TREE_ITEM_PIX (tree_item_pix)->collapsed_pixmap =
    gdk_pixmap_create_from_xpm_d (GTK_WIDGET (tree_item_pix)->window,
                                  &((tree_item_pix)->collapsed_bitmap),
                                  NULL,
                                  folder_closed);

  GTK_TREE_ITEM_PIX (tree_item_pix)->current_pixmap =
    gdk_pixmap_create_from_xpm_d (GTK_WIDGET (tree_item_pix)->window,
                                  &((tree_item_pix)->current_bitmap),
                                  NULL,
                                  folder_closed);

  GTK_TREE_ITEM_PIX (tree_item_pix)->expanded_pixmap =
    gdk_pixmap_create_from_xpm_d (GTK_WIDGET (tree_item_pix)->window,
                                  &((tree_item_pix)->expanded_bitmap),
                                  NULL,
                                  folder_opened);

  gtk_signal_connect (GTK_OBJECT (tree_item_pix), "collapse",
                      GTK_SIGNAL_FUNC (tree_item_pix_collapse), NULL);
  gtk_signal_connect (GTK_OBJECT (tree_item_pix), "expand",
                      GTK_SIGNAL_FUNC (tree_item_pix_expand), NULL);
}

GtkWidget*
gtk_tree_item_pix_new (gchar *label)
{
  GtkWidget *tree_item_pix;
  GtkWidget *label_widget;
  GtkWidget *table_widget;

  tree_item_pix = GTK_WIDGET (gtk_type_new (gtk_tree_item_pix_get_type ()));

  label_widget = gtk_label_new(label);
  gtk_misc_set_alignment (GTK_MISC (label_widget), 0.0, 0.5);
  gtk_widget_show (label_widget);

  GTK_TREE_ITEM_PIX (tree_item_pix)->current_pix_widget = gtk_pixmap_new (GTK_TREE_ITEM_PIX (tree_item_pix)->collapsed_pixmap, GTK_TREE_ITEM_PIX (tree_item_pix)->collapsed_bitmap);
  //gtk_widget_show (pixmap_widget);
  gtk_widget_show (GTK_TREE_ITEM_PIX (tree_item_pix)->current_pix_widget);

  table_widget = gtk_table_new (1, 2, FALSE);
  gtk_widget_show (table_widget);
  gtk_table_attach (GTK_TABLE (table_widget),
    GTK_TREE_ITEM_PIX (tree_item_pix)->current_pix_widget, 0, 1, 0, 1,
    GTK_SHRINK, GTK_SHRINK, 0, 0);
  gtk_table_attach (GTK_TABLE (table_widget), label_widget, 1, 2, 0, 1, GTK_SHRINK,
                               GTK_SHRINK, 0, 0);
  gtk_container_add (GTK_CONTAINER (tree_item_pix), table_widget);

  return tree_item_pix;
}

void tree_item_pix_collapse (GtkWidget *item, gpointer data)
{
  g_print ("COLLAPSE\n");
}

void tree_item_pix_expand (GtkWidget *item, gpointer data)
{
  g_print ("EXPAND\n");
  GTK_TREE_ITEM_PIX (item)->current_pix_widget = gtk_pixmap_new (GTK_TREE_ITEM_PIX (item)->expanded_pixmap, GTK_TREE_ITEM_PIX (item)->expanded_bitmap);
}
